# PyAxonaut

[![Build Status](https://travis-ci.org/antoine-briand/pyaxonaut.svg?branch=master)](https://travis-ci.org/antoine-briand/pyaxonaut)
[![codecov](https://codecov.io/gh/antoine-briand/pyaxonaut/branch/master/graph/badge.svg)](https://codecov.io/gh/antoine-briand/pyaxonaut)
[![Maintainability](https://api.codeclimate.com/v1/badges/a01882009fa085382b87/maintainability)](https://codeclimate.com/github/antoine-briand/pyaxonaut/maintainability)

Unofficial API Wrapper for Axonaut.com written in Python.